Skip to content
KitploitKITPLOIT
OutilsExploitsBlog
Log in
Soumettre
OutilsExploitsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

FluxContactConfidentialité© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
Outils/GitHubGitHub/fo-000/bluing
Sécurité AndroidReconnaissanceSécurité BluetoothSécurité IoTCollecte d'InformationsSécurité Sans Fil
GitHubfo-000/bluing

bluing

Un outil de collecte de renseignements pour le piratage Bluetooth

Voir le dépôt
1.0k13017il y a 3 ansVérifié par Kitploit

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Partager

Bluing

Un outil de collecte de renseignements pour le piratage Bluetooth

English · 简体中文

Bluing (anciennement bluescan) est un outil de collecte de renseignements Bluetooth écrit principalement en Python. Il peut nous aider à espionner la structure interne du Bluetooth, qui est un protocole complexe, ou à pirater des appareils Bluetooth. Voici les principales fonctionnalités de l'outil :

Installation

Bluing dépend partiellement de BlueZ, la pile de protocoles Bluetooth officielle de Linux. Il ne prend donc en charge que l'exécution sous Linux. La commande suivante est utilisée pour installer les dépendances :```sh sudo apt install python3-pip python3-dev libcairo2-dev libgirepository1.0-dev
libbluetooth-dev libdbus-1-dev bluez-tools python3-cairo-dev
rfkill meson patchelf bluez ubertooth adb python-is-python3

Actuellement, bluing est distribué via [PyPI](https://pypi.org/project/bluing/) et **ne supporte que Python 3.10**. Voici une commande d'installation :```sh
sudo pip3.10 install bluing

Utilisation

  • Dieu a dit : « Qu'il y ait de la couleur », et il y eut couleur.
  • Vous voudrez peut-être un aperçu rapide du matériel recommandé.
$ bluing --help
Un outil de collecte de renseignements pour le piratage Bluetooth

Utilisation :
    bluing [-h | --help]
    bluing (-v | --version)
    bluing [-i <hci>] --clean BD_ADDR
    bluing --flash-micro-bit
    bluing <commande> [<args>...]

Arguments :
    BD_ADDR    Adresse du périphérique Bluetooth

Options :
    -h, --help           Afficher cette aide et quitter
    -v, --version        Afficher les informations de version et quitter
    -i <hci>             Périphérique HCI
    --clean              Nettoyer les données en cache d'un périphérique distant
    --flash-micro-bit    Télécharger le firmware dédié sur le(s) micro:bit(s)

Commandes :
    br         Système Basic Rate, inclut une extension facultative Enhanced Data Rate (EDR)
    le         Système Low Energy
    android    Pile Bluetooth Android
    spoof      Usurper avec de nouvelles informations de périphérique local
    plugin     Gérer les plugins

Exécutez `bluing <commande> --help` pour plus d'informations sur une commande.

Commande br : système Basic Rate

$ bluing br --help
Utilisation :
    bluing br [-h | --help]
    bluing br [-i <hci>] [--inquiry-len=<n>] --inquiry
    bluing br [-i <hci>] --sdp BD_ADDR
    bluing br [-i <hci>] --local --sdp
    bluing br [-i <hci>] --lmp-features BD_ADDR
    bluing br [-i <hci>] --local --lmp-features
    bluing br [-i <hci>] --stack BD_ADDR
    bluing br [-i <hci>] --local --stack
    bluing br [-i <hci>] [--inquiry-scan] --mon-incoming-conn
    bluing br --org=<nom> --timeout=<sec> --sniff-and-guess-bd-addr

Arguments :
    BD_ADDR    Adresse du périphérique Bluetooth BR/EDR

Options :
    -h, --help                   Afficher cette aide et quitter
    -i <hci>                     Périphérique HCI
    --local                      Cibler un périphérique BR/EDR local au lieu d'un distant
    --inquiry                    Découvrir d'autres contrôleurs BR/EDR à proximité
    --inquiry-len=<n>            Durée maximale (ajoutée à --ext-inquiry-len=<n>)
                                 spécifiée avant l'arrêt de l'enquête.
                                     Temps = n * 1,28 s
                                     Plage de temps : 1,28 à 61,44 s
                                     Plage de n : 0x01 à 0x30 [défaut : 8]
    --ext-inquiry-len=<n>        Extended_Inquiry_Length mesuré en nombre de
                                 slots Baseband.
                                     Longueur d'intervalle = n * 0,625 ms (1 slot Baseband)
                                     Plage de temps : 0 à 40,9 s
                                     Plage de n : 0x0000 à 0xFFFF [défaut : 0]
    --sdp                        Récupérer les informations de la base de données SDP d'un
                                 périphérique BR/EDR distant
    --lmp-features               Lire les fonctionnalités LMP d'un périphérique BR/EDR distant
    --stack                      Déterminer le type de pile Bluetooth d'un périphérique BR/EDR distant
    --mon-incoming-conn          Afficher les connexions entrantes d'autres périphériques BR/EDR à proximité
    --inquiry-scan               Activer le balayage d'enquête (Inquiry Scan)
    --sniff-and-guess-bd-addr    Renifler les SAP des BD_ADDR dans les airs, puis deviner
                                 l'adresse en fonction du nom de l'organisation. Nécessite au
                                 moins un périphérique Ubertooth
    --org=<nom>                  Un nom d'organisation dans le fichier OUI.txt
    --timeout=<sec>              Délai d'attente en seconde(s)

--inquiry : Découvrir d'autres contrôleurs BR/EDR à proximité

$ sudo bluing br --inquiry
[INFO] Découverte d'autres contrôleurs BR/EDR à proximité sur hci0 pendant 10,24 secondes
Télécharger l’outil